@@ -98,19 +98,11 @@ enum OCLScopeKind {
 // To avoid any inconsistence here, constants are explicitly initialized with
 // the corresponding constants from 'std::memory_order' enum.
 enum OCLMemOrderKind {
-#if __cplusplus >= 202002L
-  OCLMO_relaxed = static_cast<int>(std::memory_order::relaxed),
-  OCLMO_acquire = static_cast<int>(std::memory_order::acquire),
-  OCLMO_release = static_cast<int>(std::memory_order::release),
-  OCLMO_acq_rel = static_cast<int>(std::memory_order::acq_rel),
-  OCLMO_seq_cst = static_cast<int>(std::memory_order::seq_cst)
-#else
   OCLMO_relaxed = std::memory_order::memory_order_relaxed,
   OCLMO_acquire = std::memory_order::memory_order_acquire,
   OCLMO_release = std::memory_order::memory_order_release,
   OCLMO_acq_rel = std::memory_order::memory_order_acq_rel,
   OCLMO_seq_cst = std::memory_order::memory_order_seq_cst
-#endif
 };
 
 enum IntelFPGAMemoryAccessesVal {
@@ -169,7 +161,7 @@ struct OCLBuiltinTransInfo {
   std::string Postfix; // Postfix to be added
   /// Postprocessor of operands
   std::function<void(BuiltinCallMutator &)> PostProc;
-  Type *RetTy;      // Return type of the translated function
+  Type *RetTy; // Return type of the translated function
   OCLBuiltinTransInfo() : RetTy(nullptr) {
     PostProc = [](BuiltinCallMutator &) {};
   }
@@ -461,12 +453,11 @@ SmallVector<unsigned, 3> decodeMDNode(MDNode *N);
 template <typename T> std::string getFullPath(const T *Scope) {
   if (!Scope)
     return std::string();
-  StringRef Filename = Scope->getFilename();
-  auto Style = sys::path::Style::native;
-  if (sys::path::is_absolute(Filename, Style))
-    return Filename.str();
+  std::string Filename = Scope->getFilename().str();
+  if (sys::path::is_absolute(Filename))
+    return Filename;
   SmallString<16> DirName = Scope->getDirectory();
-  sys::path::append(DirName, Style, Filename.str());
+  sys::path::append(DirName, sys::path::Style::posix, Filename);
   return DirName.str().str();
 }
 
@@ -544,17 +535,18 @@ getOrCreateSwitchFunc(StringRef MapName, Value *V,
   F->setLinkage(GlobalValue::PrivateLinkage);
 
   LLVMContext &Ctx = M->getContext();
-  BasicBlock *BB = BasicBlock::Create(Ctx, "entry", F);
-  IRBuilder<> IRB(BB);
+  BasicBlock *EntryBB = BasicBlock::Create(Ctx, "entry", F);
+  IRBuilder<> EntryIRB(EntryBB);
+  AllocaInst *Result = EntryIRB.CreateAlloca(Ty, nullptr, "result");
   SwitchInst *SI;
   F->arg_begin()->setName("key");
   if (KeyMask) {
     Value *MaskV = ConstantInt::get(Type::getInt32Ty(Ctx), KeyMask);
-    Value *NewKey = IRB.CreateAnd(MaskV, F->arg_begin());
+    Value *NewKey = EntryIRB.CreateAnd(MaskV, F->arg_begin());
     NewKey->setName("key.masked");
-    SI = IRB.CreateSwitch(NewKey, BB);
+    SI = EntryIRB.CreateSwitch(NewKey, EntryBB);
   } else {
-    SI = IRB.CreateSwitch(F->arg_begin(), BB);
+    SI = EntryIRB.CreateSwitch(F->arg_begin(), EntryBB);
   }
 
   if (!DefaultCase) {
@@ -564,20 +556,54 @@ getOrCreateSwitchFunc(StringRef MapName, Value *V,
     SI->setDefaultDest(DefaultBB);
   }
 
+  BasicBlock *ExitBB = BasicBlock::Create(Ctx, "exit", F);
+  BasicBlock *CaseBB = nullptr;
   Map.foreach ([&](int Key, int Val) {
     if (IsReverse)
       std::swap(Key, Val);
-    BasicBlock *CaseBB = BasicBlock::Create(Ctx, "case." + Twine(Key), F);
+    CaseBB = BasicBlock::Create(Ctx, "case." + Twine(Key), F);
     IRBuilder<> CaseIRB(CaseBB);
-    CaseIRB.CreateRet(CaseIRB.getInt32(Val));
-    SI->addCase(IRB.getInt32(Key), CaseBB);
+    CaseIRB.CreateStore(CaseIRB.getInt32(Val), Result);
+    CaseIRB.CreateBr(ExitBB);
+    SI->addCase(EntryIRB.getInt32(Key), CaseBB);
     if (Key == DefaultCase)
       SI->setDefaultDest(CaseBB);
   });
-  assert(SI->getDefaultDest() != BB && "Invalid default destination in switch");
+
+  ExitBB->moveAfter(CaseBB);
+  IRBuilder<> ExitIRB(ExitBB);
+  LoadInst *RetVal = ExitIRB.CreateLoad(Ty, Result, "retVal");
+  ExitIRB.CreateRet(RetVal);
+
+  assert(SI->getDefaultDest() != EntryBB &&
+         "Invalid default destination in switch");
   return addCallInst(M, MapName, Ty, V, nullptr, InsertPoint);
 }
 
+/// Maps LLVM SyncScope into SPIR-V Scope.
+///
+/// \param [in] Ctx Context for the LLVM SyncScope
+/// \param [in] Id SyncScope::ID value which needs to be mapped to SPIR-V Scope
+inline spv::Scope toSPIRVScope(const LLVMContext &Ctx, SyncScope::ID Id) {
+  // We follow Clang/LLVM convention by which the default is System scope, which
+  // in SPIR-V maps to CrossDevice scope. This is in order to ensure that the
+  // resulting SPIR-V is conservatively correct (i.e. always works), under the
+  // assumption that it is the responsibility of the higher level language to
+  // choose a narrower scope, if desired.
+  switch (Id) {
+  case SyncScope::SingleThread:
+    return spv::ScopeInvocation;
+  case SyncScope::System:
+    return spv::ScopeCrossDevice;
+  default:
+    SmallVector<StringRef> SSIDs;
+    Ctx.getSyncScopeNames(SSIDs);
+    spv::Scope S = ScopeCrossDevice; // Default to CrossDevice scope.
+    OCLStrMemScopeMap::find(SSIDs[Id].str(), &S);
+    return S;
+  }
+}
+
 /// Performs conversion from OpenCL memory_scope into SPIR-V Scope.
 ///
 /// Supports both constant and non-constant values. To handle the latter case,
