@@ -525,11 +525,6 @@ ParamType lastFuncParamType(StringRef MangledName) {
   char Mangled = Copy.back();
   std::string Mangled2 = Copy.substr(Copy.size() - 2);
 
-  std::string Mangled5 = Copy.substr(Copy.size() - 5);
-  if (Mangled5 == "DF16b") {
-    return ParamType::FLOAT;
-  }
-
   if (isMangledTypeFP(Mangled) || isMangledTypeHalf(Mangled2)) {
     return ParamType::FLOAT;
   } else if (isMangledTypeUnsigned(Mangled)) {
@@ -611,21 +606,6 @@ static Type *parsePrimitiveType(LLVMContext &Ctx, StringRef Name) {
 
 } // namespace SPIRV
 
-namespace {
-
-// Return the value for when the dimension index of a builtin is out of range.
-uint64_t getBuiltinOutOfRangeValue(StringRef VarName) {
-  assert(VarName.starts_with("__spirv_BuiltIn"));
-  return StringSwitch<uint64_t>(VarName)
-      .EndsWith("GlobalSize", 1)
-      .EndsWith("NumWorkgroups", 1)
-      .EndsWith("WorkgroupSize", 1)
-      .EndsWith("EnqueuedWorkgroupSize", 1)
-      .Default(0);
-}
-
-} // anonymous namespace
-
 // The demangler node hierarchy doesn't use LLVM's RTTI helper functions (as it
 // also needs to live in libcxxabi). By specializing this implementation here,
 // we can add support for these functions.
@@ -1343,8 +1323,6 @@ static SPIR::RefParamType transTypeDesc(Type *Ty,
     return SPIR::RefParamType(new SPIR::PrimitiveType(SPIR::PRIMITIVE_FLOAT));
   if (Ty->isDoubleTy())
     return SPIR::RefParamType(new SPIR::PrimitiveType(SPIR::PRIMITIVE_DOUBLE));
-  if (Ty->isBFloatTy())
-    return SPIR::RefParamType(new SPIR::PrimitiveType(SPIR::PRIMITIVE_BFLOAT));
   if (auto *VecTy = dyn_cast<FixedVectorType>(Ty)) {
     return SPIR::RefParamType(new SPIR::VectorType(
         transTypeDesc(VecTy->getElementType(), Info), VecTy->getNumElements()));
@@ -1916,9 +1894,6 @@ bool checkTypeForSPIRVExtendedInstLowering(IntrinsicInst *II, SPIRVModule *BM) {
       NumElems = VecTy->getNumElements();
       Ty = VecTy->getElementType();
     }
-    if (Ty->isBFloatTy() &&
-        BM->hasCapability(internal::CapabilityBFloat16ArithmeticINTEL))
-      return true;
     if ((!Ty->isFloatTy() && !Ty->isDoubleTy() && !Ty->isHalfTy()) ||
         (!BM->hasCapability(CapabilityVectorAnyINTEL) &&
          ((NumElems > 4) && (NumElems != 8) && (NumElems != 16)))) {
@@ -1935,9 +1910,6 @@ bool checkTypeForSPIRVExtendedInstLowering(IntrinsicInst *II, SPIRVModule *BM) {
       NumElems = VecTy->getNumElements();
       Ty = VecTy->getElementType();
     }
-    if (Ty->isBFloatTy() &&
-        BM->hasCapability(internal::CapabilityBFloat16ArithmeticINTEL))
-      return true;
     if ((!Ty->isIntegerTy()) ||
         (!BM->hasCapability(CapabilityVectorAnyINTEL) &&
          ((NumElems > 4) && (NumElems != 8) && (NumElems != 16)))) {
@@ -2210,27 +2182,16 @@ bool lowerBuiltinCallsToVariables(Module *M) {
     for (auto *U : F.users()) {
       auto *CI = dyn_cast<CallInst>(U);
       assert(CI && "invalid instruction");
-      IRBuilder<> Builder(CI);
-      Value *NewValue = Builder.CreateLoad(GVType, BV);
+      const DebugLoc &DLoc = CI->getDebugLoc();
+      Instruction *NewValue = new LoadInst(GVType, BV, "", CI->getIterator());
+      if (DLoc)
+        NewValue->setDebugLoc(DLoc);
       LLVM_DEBUG(dbgs() << "Transform: " << *CI << " => " << *NewValue << '\n');
       if (IsVec) {
-        auto *GVVecTy = cast<FixedVectorType>(GVType);
-        ConstantInt *Bound = Builder.getInt32(GVVecTy->getNumElements());
-        // Create a select on the index first, to avoid undefined behaviour
-        // due to exceeding the vector size by the extractelement.
-        Value *IndexCmp = Builder.CreateICmpULT(CI->getArgOperand(0), Bound);
-        Constant *ZeroIndex =
-            ConstantInt::get(CI->getArgOperand(0)->getType(), 0);
-        Value *ExtractIndex =
-            Builder.CreateSelect(IndexCmp, CI->getArgOperand(0), ZeroIndex);
-
-        // Extract from builtin variable.
-        NewValue = Builder.CreateExtractElement(NewValue, ExtractIndex);
-
-        // Clamp to out-of-range value.
-        Constant *OutOfRangeVal = ConstantInt::get(
-            F.getReturnType(), getBuiltinOutOfRangeValue(BuiltinVarName));
-        NewValue = Builder.CreateSelect(IndexCmp, NewValue, OutOfRangeVal);
+        NewValue = ExtractElementInst::Create(NewValue, CI->getArgOperand(0),
+                                              "", CI->getIterator());
+        if (DLoc)
+          NewValue->setDebugLoc(DLoc);
         LLVM_DEBUG(dbgs() << *NewValue << '\n');
       }
       NewValue->takeName(CI);
