@@ -339,7 +339,10 @@ public:
   bool isUndef() const { return OpCode == OpUndef; }
   bool isControlBarrier() const { return OpCode == OpControlBarrier; }
   bool isMemoryBarrier() const { return OpCode == OpMemoryBarrier; }
-  bool isVariable() const { return OpCode == OpVariable; }
+  bool isVariable() const {
+    return OpCode == OpVariable || OpCode == OpUntypedVariableKHR;
+  }
+  bool isUntypedVariable() const { return OpCode == OpUntypedVariableKHR; }
   bool isEndOfBlock() const;
   virtual bool isInst() const { return false; }
   virtual bool isOperandLiteral(unsigned Index) const {
@@ -907,15 +910,12 @@ public:
     case CapabilityVectorComputeINTEL:
     case CapabilityVectorAnyINTEL:
       return ExtensionID::SPV_INTEL_vector_compute;
+    case internal::CapabilityFastCompositeINTEL:
+      return ExtensionID::SPV_INTEL_fast_composite;
     case internal::CapabilitySubgroupRequirementsINTEL:
       return ExtensionID::SPV_INTEL_subgroup_requirements;
     case CapabilityFPFastMathModeINTEL:
       return ExtensionID::SPV_INTEL_fp_fast_math_mode;
-    case CapabilityFunctionVariantsINTEL:
-    case CapabilitySpecConditionalINTEL:
-      return ExtensionID::SPV_INTEL_function_variants;
-    case internal::CapabilityBFloat16ArithmeticINTEL:
-      return ExtensionID::SPV_INTEL_bfloat16_arithmetic;
     default:
       return {};
     }
@@ -968,7 +968,7 @@ public:
   }
 
   std::optional<ExtensionID> getRequiredExtension() const override {
-    return ExtensionID::SPV_INTEL_long_constant_composite;
+    return ExtensionID::SPV_INTEL_long_composites;
   }
 
   SPIRVWord getNumElements() const { return Elements.size(); }
