@@ -221,23 +221,8 @@ template <> inline void SPIRVMap<SPIRVCapabilityKind, SPIRVCapVec>::init() {
                {CapabilityCooperativeMatrixKHR});
   ADD_VEC_INIT(internal::CapabilityCooperativeMatrixCheckedInstructionsINTEL,
                {CapabilityCooperativeMatrixKHR});
-  ADD_VEC_INIT(CapabilityBFloat16DotProductKHR, {CapabilityBFloat16TypeKHR});
-  ADD_VEC_INIT(CapabilityBFloat16CooperativeMatrixKHR,
-               {CapabilityBFloat16TypeKHR, CapabilityCooperativeMatrixKHR});
-  ADD_VEC_INIT(CapabilityInt4CooperativeMatrixINTEL,
-               {CapabilityInt4TypeINTEL, CapabilityCooperativeMatrixKHR});
-  ADD_VEC_INIT(internal::CapabilityBFloat16ArithmeticINTEL,
-               {CapabilityBFloat16TypeKHR});
-  ADD_VEC_INIT(internal::CapabilityAtomicInt16CompareExchangeINTEL,
-               {CapabilityInt16});
-  ADD_VEC_INIT(internal::CapabilityInt16AtomicsINTEL,
-               {internal::CapabilityAtomicInt16CompareExchangeINTEL});
-  ADD_VEC_INIT(internal::CapabilityAtomicBFloat16LoadStoreINTEL,
-               {CapabilityBFloat16TypeKHR});
-  ADD_VEC_INIT(internal::CapabilityAtomicBFloat16AddINTEL,
-               {CapabilityBFloat16TypeKHR});
-  ADD_VEC_INIT(internal::CapabilityAtomicBFloat16MinMaxINTEL,
-               {CapabilityBFloat16TypeKHR});
+  ADD_VEC_INIT(internal::CapabilityCooperativeMatrixOffsetInstructionsINTEL,
+               {CapabilityCooperativeMatrixKHR});
 }
 
 template <> inline void SPIRVMap<SPIRVExecutionModelKind, SPIRVCapVec>::init() {
@@ -300,6 +285,8 @@ template <> inline void SPIRVMap<SPIRVExecutionModeKind, SPIRVCapVec>::init() {
                {CapabilityFloatingPointModeINTEL});
   ADD_VEC_INIT(ExecutionModeSharedLocalMemorySizeINTEL,
                {CapabilityVectorComputeINTEL});
+  ADD_VEC_INIT(internal::ExecutionModeFastCompositeKernelINTEL,
+               {internal::CapabilityFastCompositeINTEL});
   ADD_VEC_INIT(ExecutionModeRegisterMapInterfaceINTEL,
                {CapabilityFPGAKernelAttributesv2INTEL});
   ADD_VEC_INIT(ExecutionModeStreamingInterfaceINTEL,
@@ -409,6 +396,7 @@ template <> inline void SPIRVMap<Decoration, SPIRVCapVec>::init() {
   ADD_VEC_INIT(DecorationSample, {CapabilitySampleRateShading});
   ADD_VEC_INIT(DecorationInvariant, {CapabilityShader});
   ADD_VEC_INIT(DecorationConstant, {CapabilityKernel});
+  ADD_VEC_INIT(DecorationUniform, {CapabilityShader});
   ADD_VEC_INIT(DecorationSaturatedConversion, {CapabilityKernel});
   ADD_VEC_INIT(DecorationStream, {CapabilityGeometryStreams});
   ADD_VEC_INIT(DecorationLocation, {CapabilityShader});
@@ -481,6 +469,8 @@ template <> inline void SPIRVMap<Decoration, SPIRVCapVec>::init() {
   ADD_VEC_INIT(DecorationAliasScopeINTEL,
                {CapabilityMemoryAccessAliasingINTEL});
   ADD_VEC_INIT(DecorationNoAliasINTEL, {CapabilityMemoryAccessAliasingINTEL});
+  ADD_VEC_INIT(internal::DecorationCallableFunctionINTEL,
+               {internal::CapabilityFastCompositeINTEL});
   ADD_VEC_INIT(DecorationMediaBlockIOINTEL, {CapabilityVectorComputeINTEL});
   ADD_VEC_INIT(DecorationStallEnableINTEL,
                {CapabilityFPGAClusterAttributesINTEL});
